@@ -3,8 +3,7 @@
 import logging
 from typing import Optional
 
-import pkg_resources
-
+from ._version import __version__  # noqa: F401
 from .client import Client  # noqa: F401
 from .exceptions import (  # noqa: F401
     ClientValueError,
@@ -13,8 +12,6 @@ from .exceptions import (  # noqa: F401
     ResponseError,
 )
 
-__version__ = pkg_resources.get_distribution(__name__).version
-
 
 def set_stream_logger(
     name: str = __name__, level: int = logging.INFO, format_string: Optional[str] = None
